@@ -1,7 +1,9 @@
 #!/usr/bin/python
-# coding: utf-8
+# pylint: disable=invalid-name
 
+from typing import Any, Dict, List
 
+import sphinx.application
 from docutils import nodes
 from docutils.parsers import rst
 from docutils.parsers.rst import directives
@@ -14,33 +16,34 @@ logger = logging.getLogger(__name__)
 
 
 class PromptCache:
-    def __init__(self):
-        self.clear()
+    def __init__(self) -> None:
+        self.next_index = 1
+        self.prompts: Dict[str, int] = {}
 
-    def clear(self, *ignored):
-        # ignored parameters allow this method to be used as event handler
+    def clear(self, *args: Any) -> None:
+        del args
         self.next_index = 1
         self.prompts = {}
 
-    def register_prompt(self, prompt):
+    def register_prompt(self, prompt: str) -> str:
         if prompt in self.prompts:
             return ""
         else:
             index = self.next_index
             self.next_index = index + 1
             self.prompts[prompt] = index
-            return """span.prompt{0:d}:before {{
-  content: "{1!s} ";
+            return """span.prompt{}:before {{
+  content: "{} ";
 }}
 """.format(
                 index, prompt
             )
 
-    def get_prompt_class(self, prompt):
-        return "prompt{0:d}".format(self.prompts[prompt])
+    def get_prompt_class(self, prompt: str) -> str:
+        return f"prompt{self.prompts[prompt]}"
 
 
-cache = PromptCache()
+_cache = PromptCache()
 PROMPTS = {
     "bash": "$",
     "batch": r"C:\\>",
@@ -55,7 +58,7 @@ LEXERS = {
 }
 
 
-class PromptDirective(rst.Directive):
+class PromptDirective(rst.Directive):  # type: ignore
 
     optional_arguments = 3
     option_spec = {
@@ -65,13 +68,9 @@ class PromptDirective(rst.Directive):
     }
     has_content = True
 
-    def run(self):
+    def run(self) -> List[nodes.raw]:
         self.assert_has_content()
 
-        language = "text"
-        prompt = None
-        modifiers = []
-
         arg_count = len(self.arguments)
 
         for idx, option_name in enumerate(("language", "prompts", "modifiers")):
@@ -87,27 +86,27 @@ class PromptDirective(rst.Directive):
                 else:
                     self.options[option_name] = self.arguments[idx]
 
-        language = self.options.get("language") or "text"
-        prompt = self.options.get("prompts") or PROMPTS.get(language, "")
-        modifiers = self.options.get("modifiers", "").split(",")
+        language: str = self.options.get("language") or "text"
+        prompt: str = self.options.get("prompts") or PROMPTS.get(language, "")
+        modifiers: List[str] = self.options.get("modifiers", "").split(",")
         if "auto" in modifiers:
-            prompts = prompt.split(",")
+            prompts: List[str] = prompt.split(",")
 
         html = '<div class="highlight-default notranslate"><div class="highlight"><pre>'
         styles = ""
         if "auto" in modifiers:
             for prompt in prompts:
-                styles += cache.register_prompt(prompt)
+                styles += _cache.register_prompt(prompt)
         else:
             if prompt is not None:
-                styles += cache.register_prompt(prompt)
+                styles += _cache.register_prompt(prompt)
         if styles:
             html += '<style type="text/css">\n' + styles + "</style>"
         latex = "\\begin{Verbatim}[commandchars=\\\\\\{\\}]"
 
-        Lexer = LEXERS.get(language, TextLexer)
+        Lexer = LEXERS.get(language, TextLexer)  # noqa: N806, pylint: disable=invalid-name
 
-        statement = []
+        statement: List[str] = []
         if "auto" in modifiers:
             prompt_class = ""
             for line in self.content:
@@ -116,7 +115,7 @@ class PromptDirective(rst.Directive):
                 for prompt in prompts:
                     if line.startswith(prompt):
                         if len(statement) > 0:
-                            html += '<span class="{0!s}">{1!s}</span>\n'.format(
+                            html += '<span class="{}">{}</span>\n'.format(
                                 prompt_class,
                                 highlight("\n".join(statement), Lexer(), HtmlFormatter(nowrap=True)).strip(
                                     "\r\n"
@@ -124,13 +123,13 @@ class PromptDirective(rst.Directive):
                             )
                             statement = []
                         line = line[len(prompt) + 1 :].rstrip()
-                        prompt_class = cache.get_prompt_class(prompt)
+                        prompt_class = _cache.get_prompt_class(prompt)
                         break
 
                 statement.append(line)
             # Add last prompt
             if len(statement) > 0:
-                html += '<span class="{0!s}">{1!s}</span>\n'.format(
+                html += '<span class="{}">{}</span>\n'.format(
                     prompt_class,
                     highlight("\n".join(statement), Lexer(), HtmlFormatter(nowrap=True)).strip("\r\n"),
                 )
@@ -138,23 +137,23 @@ class PromptDirective(rst.Directive):
             for line in self.content:
                 statement.append(line)
                 if len(line) == 0 or not line[-1] == "\\":
-                    html += '<span class="{0!s}">{1!s}</span>\n'.format(
-                        cache.get_prompt_class(prompt),
+                    html += '<span class="{}">{}</span>\n'.format(
+                        _cache.get_prompt_class(prompt),
                         highlight("\n".join(statement), Lexer(), HtmlFormatter(nowrap=True)).strip("\r\n"),
                     )
                     if prompt is not None:
-                        latex += "\n{0!s} {1!s}".format(prompt, "\n".join(statement))
+                        latex += "\n{} {}".format(prompt, "\n".join(statement))
                     else:
                         latex += "\n" + "\n".join(statement)
                     statement = []
         else:
             for line in self.content:
-                html += '<span class="{0!s}">{1!s}</span>\n'.format(
-                    cache.get_prompt_class(prompt),
+                html += '<span class="{}">{}</span>\n'.format(
+                    _cache.get_prompt_class(prompt),
                     highlight(line, Lexer(), HtmlFormatter(nowrap=True)).strip("\r\n"),
                 )
                 if prompt is not None:
-                    latex += "\n{0!s} {1!s}".format(prompt, line)
+                    latex += f"\n{prompt} {line}"
                 else:
                     latex += "\n" + line
 
@@ -167,9 +166,9 @@ class PromptDirective(rst.Directive):
         ]
 
 
-def setup(app):
+def setup(app: sphinx.application.Sphinx) -> Dict[str, bool]:
     app.add_directive("prompt", PromptDirective)
-    app.connect("env-purge-doc", cache.clear)
+    app.connect("env-purge-doc", _cache.clear)
     return {
         "parallel_read_safe": True,
         "parallel_write_safe": True,
